// src/index.js
import { icon, library } from "@fortawesome/fontawesome-svg-core";
import out from "@snickbit/out";

// src/utilities/data.js
var default_icon_map = {
  name: "svg-fontawesome-v6-pro",
  type: {
    positive: "fa:circle-check",
    negative: "fa:triangle-exclamation",
    info: "fa:circle-info",
    warning: "fa:exclamation"
  },
  arrow: {
    up: "fa:arrow-up",
    right: "fa:arrow-right",
    down: "fa:arrow-down",
    left: "fa:arrow-left",
    dropdown: "fa:caret-down"
  },
  chevron: {
    left: "fa:chevron-left",
    right: "fa:chevron-right"
  },
  colorPicker: {
    spectrum: "fa:eye-dropper",
    tune: "fa:sliders",
    palette: "fa:swatchbook"
  },
  pullToRefresh: {
    icon: "fa:arrows-rotate"
  },
  carousel: {
    left: "fa:chevron-left",
    right: "fa:chevron-right",
    up: "fa:chevron-up",
    down: "fa:chevron-down",
    navigationIcon: "fa:circle"
  },
  chip: {
    remove: "fa:circle-xmark",
    selected: "fa:circle-check"
  },
  datetime: {
    arrowLeft: "fa:chevron-left",
    arrowRight: "fa:chevron-right",
    now: "fa:clock",
    today: "fa:calendar-check"
  },
  editor: {
    bold: "fa:bold",
    italic: "fa:italic",
    strikethrough: "fa:strikethrough",
    underline: "fa:underline",
    unorderedList: "fa:list-ul",
    orderedList: "fa:list-ol",
    subscript: "fa:subscript",
    superscript: "fa:superscript",
    hyperlink: "fa:link",
    toggleFullscreen: "fa:maximize",
    quote: "fa:quote-right",
    left: "fa:align-left",
    center: "fa:align-center",
    right: "fa:align-right",
    justify: "fa:align-justify",
    print: "fa:print",
    outdent: "fa:outdent",
    indent: "fa:indent",
    removeFormat: "fa:eraser",
    formatting: "fa:heading",
    fontSize: "fa:text-height",
    align: "fa:align-left",
    hr: "fa:square-minus",
    undo: "fa:rotate-left",
    redo: "fa:rotate-right",
    heading: "fa:heading",
    code: "fa:code",
    size: "fa:text-height",
    font: "fa:font",
    viewSource: "fa:code"
  },
  expansionItem: {
    icon: "fa:chevron-down",
    denseIcon: "fa:caret-down"
  },
  fab: {
    icon: "fa:plus",
    activeIcon: "fa:xmark"
  },
  field: {
    clear: "fa:circle-xmark",
    error: "fa:circle-exclamation"
  },
  pagination: {
    first: "fa:backward-step",
    prev: "fa:chevron-left",
    next: "fa:chevron-right",
    last: "fa:forward-step"
  },
  rating: {
    icon: "fa:star"
  },
  stepper: {
    done: "fa:circle-check",
    active: "fa:pencil",
    error: "fa:triangle-exclamation"
  },
  tabs: {
    left: "fa:chevron-left",
    right: "fa:chevron-right",
    up: "fa:chevron-up",
    down: "fa:chevron-down"
  },
  table: {
    arrowUp: "fa:long-arrow-up",
    warning: "fa:triangle-exclamation",
    firstPage: "fa:backward-step",
    prevPage: "fa:chevron-left",
    nextPage: "fa:chevron-right",
    lastPage: "fa:forward-step"
  },
  tree: {
    icon: "fa:play"
  },
  uploader: {
    done: "fa:circle-check",
    clear: "fa:xmark",
    add: "fa:square-plus",
    upload: "fa:upload",
    removeQueue: "fa:bars-staggered",
    removeUploaded: "fa:clipboard-check"
  }
};

// src/index.js
async function useFa(app, icon_aliases) {
  var _a;
  out.verbose("Loading Font Awesome icons...");
  const definitions = ((_a = library) == null ? void 0 : _a.definitions) || {};
  let iconDefaultPrefixes = {};
  for (let [prefixName, prefixGroup] of Object.entries(definitions)) {
    for (let prefixIconName in prefixGroup) {
      (iconDefaultPrefixes[prefixIconName] = iconDefaultPrefixes[prefixIconName] || []).push(prefixName);
    }
  }
  function parseIcon(iconData) {
    let [width, height, ligatures, unicode, svgPathData] = iconData.icon;
    if (ligatures.length < 2 || iconData.prefix !== "fad") {
      ligatures = [0, 0];
    }
    if (Array.isArray(svgPathData)) {
      for (let svgIndex of svgPathData.keys()) {
        if (!svgPathData[svgIndex].includes("@@fill: var")) {
          if (svgIndex === 0) {
            svgPathData[svgIndex] += "@@fill: var(--fa-secondary-color, currentColor);opacity: 0.4;opacity: var(--fa-secondary-opacity, 0.4);";
          } else if (svgIndex === 1) {
            svgPathData[svgIndex] += "@@fill: var(--fa-primary-color, currentColor);opacity: 1;opacity: var(--fa-primary-opacity, 1);";
          }
        }
      }
      svgPathData = svgPathData.join("&&");
    }
    return svgPathData + "|" + ligatures.join(" ") + " " + width + " " + height;
  }
  function splitIconName(icon_name) {
    let prefix = "fa";
    if (icon_name.includes(":")) {
      [prefix, icon_name] = icon_name.split(":");
    }
    let prefixed_icon_name = `${prefix}:${icon_name}`;
    if (icon_aliases.hasOwnProperty(icon_name)) {
      prefixed_icon_name = icon_aliases[icon_name];
    } else if (icon_aliases.hasOwnProperty(prefixed_icon_name)) {
      prefixed_icon_name = icon_aliases[prefixed_icon_name];
    }
    return prefixed_icon_name.includes(":") ? prefixed_icon_name.split(":") : [
      prefix,
      prefixed_icon_name
    ];
  }
  function parseIconName(raw_icon_name) {
    let [prefix, iconName] = splitIconName(raw_icon_name);
    if (prefix === "fa" && iconDefaultPrefixes.hasOwnProperty(iconName) && iconDefaultPrefixes[iconName].length === 1) {
      prefix = iconDefaultPrefixes[iconName].slice().pop();
    }
    return {
      iconName,
      prefix
    };
  }
  app.config.globalProperties.$q.iconSet.set(default_icon_map);
  app.config.globalProperties.$q.iconMapFn = (icon_name) => {
    let parsedIconName = parseIconName(icon_name);
    let foundIcon = icon(parsedIconName);
    if (foundIcon) {
      return {
        cls: "svg-inline--fa",
        icon: parseIcon(foundIcon)
      };
    }
  };
}
export {
  useFa
};
